<?php

namespace Justin\ThreadPreview\XF\Pub\Controller;

use XF\Mvc\ParameterBag;

class Thread extends XFCP_Thread
{
	public function actionShow(ParameterBag $params)
	{
		//Get Thread
		$thread = $this->assertViewableThread($params->thread_id);
		$options = \XF::app()->options;
		
		$displayType = $options->j_tp_display_type;
		
		
		$posts = array();
		
		if(isset($displayType['1'])  && $displayType['1'] )//First Post display type
		{
			$posts['firstpost'] = $this->assertViewablePost($thread->first_post_id);
		}
		
		if(isset($displayType['2'])  && $displayType['2']) //Last Post display type
		{
			$posts['lastpost'] = $this->assertViewablePost($thread->last_post_id);
		}
		
		if(isset($displayType['3'])  && $displayType['3']) //Unread Post display type
		{
			$postRepo = $this->getPostRepo();
			$firstUnreadDate = $thread->getVisitorReadDate();
			$findFirstUnread = $postRepo->findNextPostsInThread($thread, $firstUnreadDate);
			$firstUnread = $findFirstUnread->skipIgnored()->fetchOne();
			if ($firstUnread)
			{
				$posts['Unread'] = $this->assertViewablePost($firstUnread->post_id);
			}
			
		}

		$viewParams = [
			'posts' => $posts,
			'thread' => $thread,
			'forum' => $thread->Forum,
			'canInlineMod' => $thread->canUseInlineModeration()
		];
		return $this->view('XF:Post\Show', 'j_threadpreview_post', $viewParams);
		
	}
	
	
	/**
	 * @param $postId
	 * @param array $extraWith
	 *
	 * @return \XF\Entity\Post
	 *
	 * @throws \XF\Mvc\Reply\Exception
	 */
	protected function assertViewablePost($postId, array $extraWith = [])
	{
		$visitor = \XF::visitor();
		$extraWith[] = 'Thread';
		$extraWith[] = 'Thread.Forum';
		$extraWith[] = 'Thread.Forum.Node';
		$extraWith[] = 'Thread.Forum.Node.Permissions|' . $visitor->permission_combination_id;

		/** @var \XF\Entity\Post $post */
		$post = $this->em()->find('XF:Post', $postId, $extraWith);
		if (!$post)
		{
			throw $this->exception($this->notFound(\XF::phrase('requested_post_not_found')));
		}
		if (!$post->canView($error))
		{
			throw $this->exception($this->noPermission($error));
		}

		$this->plugin('XF:Node')->applyNodeContext($post->Thread->Forum->Node);

		return $post;
	}

	

}